@@ -1,12 +1,12 @@
 #' Add rows to a data frame
 #'
 #' This is a convenient way to add one or more rows of data to an existing data
-#' frame. See \code{\link{tribble}} for an easy way to create an complete
+#' frame. See [tribble()] for an easy way to create an complete
 #' data frame row-by-row.
 #'
 #' @param .data Data frame to append to.
 #' @param ... Name-value pairs. If you don't supply the name of a variable,
-#'   it'll be given the value \code{NA}.
+#'   it'll be given the value `NA`.
 #' @param .before,.after One-based row index where to add the new rows,
 #'   default: after last row
 #' @family addition
@@ -32,6 +32,10 @@
 #' }
 #' @export
 add_row <- function(.data, ..., .before = NULL, .after = NULL) {
+  if (inherits(.data, "grouped_df")) {
+    stop("Cannot add rows to grouped data frames", call. = FALSE)
+  }
+
   df <- tibble(...)
   attr(df, "row.names") <- .set_row_names(max(1L, nrow(df)))
 
@@ -47,15 +51,7 @@ add_row <- function(.data, ..., .before = NULL, .after = NULL) {
   df <- df[names(.data)]
 
   pos <- pos_from_before_after(.before, .after, nrow(.data))
-
-  if (pos <= 0L) {
-    out <- rbind(df, .data)
-  } else if (pos >= nrow(.data)) {
-    out <- rbind(.data, df)
-  } else {
-    indexes <- seq_len(pos)
-    out <- rbind(.data[indexes, ], df, .data[-indexes, ])
-  }
+  out <- rbind_at(.data, df, pos)
 
   set_class(remove_rownames(out), class(.data))
 }
@@ -67,6 +63,23 @@ na_value <- function(boilerplate) {
     NA
 }
 
+rbind_at <- function(old, new, pos) {
+  if (nrow(old) == 0) {
+    old <- old[1, ]
+    out <- rbind(old, new)[-1, ]
+  } else {
+    if (pos <= 0L) {
+      out <- rbind(new, old)
+    } else if (pos >= nrow(old)) {
+      out <- rbind(old, new)
+    } else {
+      indexes <- seq_len(pos)
+      out <- rbind(old[indexes, ], new, old[-indexes, ])
+    }
+  }
+  out
+}
+
 #' Add columns to a data frame
 #'
 #' This is a convenient way to add one or more columns to an existing data
@@ -102,7 +115,11 @@ add_column <- function(.data, ..., .before = NULL, .after = NULL) {
   }
 
   if (nrow(df) != nrow(.data)) {
-    stopc("Expected ", nrow(.data), " rows, got ", nrow(df))
+    if (nrow(df) == 1) {
+      df <- df[rep(1L, nrow(.data)), ]
+    } else {
+      stopc("Expected ", nrow(.data), " rows, got ", nrow(df))
+    }
   }
 
   extra_vars <- intersect(names(df), names(.data))
