@@ -10,8 +10,8 @@ as.data.frame.tbl_df <- function(x, row.names = NULL, optional = FALSE, ...) {
 
 #' @rdname formatting
 #' @export
-print.tbl_df <- function(x, ..., n = NULL, width = NULL) {
-  print(trunc_mat(x, n = n, width = width))
+print.tbl_df <- function(x, ..., n = NULL, width = NULL, n_extra = NULL) {
+  print(trunc_mat(x, n = n, width = width, n_extra = n_extra))
   invisible(x)
 }
 
@@ -31,7 +31,7 @@ print.tbl_df <- function(x, ..., n = NULL, width = NULL) {
 #' @export
 `$.tbl_df` <- function(x, i) {
   if (is.character(i) && !has_name(x, i)) {
-    warningc("Unknown column '", i, "'")
+    warningc("Unknown or uninitialised column: '", i, "'.")
   }
   .subset2(x, i)
 }
