@@ -123,3 +123,16 @@ test_that("trunc_mat backticks non-syntactic names", {
   expect_equal(names(narrow$table), "`:)`")
   expect_equal(names(narrow$extra), "` `")
 })
+
+test_that("trunc_mat backticks NA names", {
+  tb <- tibble(
+    x = 1,
+    y = 2,
+    z = 3
+  )
+  ## there must be at least 2 NA names
+  colnames(tb)[1:2] <- NA
+  narrow <- trunc_mat(tb, width = 5)
+  expect_equal(names(narrow$table), "`NA`")
+  expect_equal(names(narrow$extra), c("`NA`", "z"))
+})
